@@ -360,6 +360,7 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 	 */
         return &sv_yes;
     }
+        
     if (kl == 5  &&  strEQ(key, "errno")) {
 #if defined(DBD_MYSQL)  &&  defined(mysql_errno)
 	return sv_2mortal(newSViv((IV)mysql_errno(imp_dbh->svsock)));
@@ -369,6 +370,11 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
     } else if (kl == 6  &&  strEQ(key, "errmsg")) {
 	char* msg = MyError(imp_dbh->svsock);
 	return sv_2mortal(newSVpv(msg, strlen(msg)));
+    } else if (kl == 4  &&  strEQ(key, "info")) {
+        char* info = mysql_info(imp_dbh->svsock);
+        return info ? sv_2mortal(newSVpv(info, strlen(info))) : &sv_undef;
+    } else if (kl == 9  &&  strEQ(key, "thread_id")) {
+        return sv_2mortal(newSViv(mysql_thread_id(imp_dbh->svsock)));
     }
     return Nullsv;
 }
@@ -394,6 +400,7 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 int dbd_st_prepare(SV* sth, imp_sth_t* imp_sth, char* statement, SV* attribs) {
     int i;
 
+
     /*
      *  Count the number of parameters
      */
@@ -405,10 +412,24 @@ int dbd_st_prepare(SV* sth, imp_sth_t* imp_sth, char* statement, SV* attribs) {
     imp_sth->done_desc = 0;
     imp_sth->cda = NULL;
     imp_sth->currow = 0;
+    imp_sth->use_mysql_use_result = 0;
     for (i = 0;  i < AV_ATTRIB_LAST;  i++) {
 	imp_sth->av_attr[i] = Nullav;
     }
 
+    /*
+     *  Check attributes
+     */
+    if (attribs  &&  SvTYPE(attribs) == SVt_RV) {
+        SV* sv = SvRV(attribs);
+	if (SvTYPE(sv) == SVt_PVHV) {
+	    SV** svp = hv_fetch((HV*) sv, "mysql_use_result", 16, FALSE);
+	    if (svp) {
+	        imp_sth->use_mysql_use_result = SvTRUE(*svp);
+	    }
+	}
+    }
+
     /*
      *  Allocate memory for parameters
      */
@@ -438,7 +459,7 @@ int dbd_st_prepare(SV* sth, imp_sth_t* imp_sth, char* statement, SV* attribs) {
 
 int dbd_st_internal_execute(SV* h, SV* statement, SV* attribs, int numParams,
 			    imp_sth_ph_t* params, result_t* cdaPtr,
-			    dbh_t svsock) {
+			    dbh_t svsock, int use_mysql_use_result) {
     STRLEN slen;
     char* sbuf = SvPV(statement, slen);
     char* salloc = ParseParam(sbuf, &slen, params, numParams);
@@ -495,7 +516,8 @@ int dbd_st_internal_execute(SV* h, SV* statement, SV* attribs, int numParams,
 	Safefree(salloc);
 
 	/** Store the result from the Query */
-	if (!(*cdaPtr = MyStoreResult(svsock))) {
+	if (!(*cdaPtr = (use_mysql_use_result ?
+		 mysql_use_result(svsock) : mysql_store_result(svsock)))) {
 	    return mysql_affected_rows(svsock);
 	}
 
@@ -543,11 +565,13 @@ int dbd_st_execute(SV* sth, imp_sth_t* imp_sth) {
     }
 
     statement = hv_fetch((HV*) SvRV(sth), "Statement", 9, FALSE);
-    if ((imp_sth->row_num = dbd_st_internal_execute(sth, *statement, NULL,
-						    DBIc_NUM_PARAMS(imp_sth),
-						    imp_sth->params,
-						    &imp_sth->cda,
-						    imp_dbh->svsock))
+    if ((imp_sth->row_num =
+	     dbd_st_internal_execute(sth, *statement, NULL,
+				     DBIc_NUM_PARAMS(imp_sth),
+				     imp_sth->params,
+				     &imp_sth->cda,
+				     imp_dbh->svsock,
+				     imp_sth->use_mysql_use_result))
 	!= -2) {
 	if (!imp_sth->cda) {
 	    imp_sth->insertid = mysql_insert_id(imp_dbh->svsock);
@@ -760,6 +784,10 @@ int dbd_st_STORE_attrib(SV* sth, imp_sth_t* imp_sth, SV* keysv, SV* valuesv) {
 		(u_long) sth, key);
     }
 
+    if (strEQ(key, "mysql_use_result")) {
+        imp_sth->use_mysql_use_result = SvTRUE(valuesv);
+    }
+
     if (dbis->debug >= 2) {
         fprintf(DBILOGFP,
 		"    <- dbd_st_STORE_attrib for %08lx, result %d\n",
@@ -1053,6 +1081,8 @@ SV* dbd_st_FETCH_attrib(SV* sth, imp_sth_t* imp_sth, SV* keysv) {
       case 'm':
 	if (strEQ(key, "max_length")) {
 	    retsv = ST_FETCH_AV(AV_ATTRIB_MAX_LENGTH);
+	} else if (strEQ(key, "mysql_use_result")) {
+	    retsv = boolSV(imp_sth->use_mysql_use_result);
 	}
 	break;
       case 'r':
