@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0092';
+$VERSION = '2.0094';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -351,6 +351,17 @@ These methods should be used at your own risk.
 =back
 
 
+=head1 DATABASE HANDLES
+
+The DBD::mysql driver supports the following attributes of database
+handles (read only):
+
+    $infoString = $dbh->{'info'};
+    $threadId = $dbh->{'thread_id'};
+
+These correspond to mysql_info() and mysql_tread_id(), respectively.
+
+
 =head1 STATEMENT HANDLES
 
 The statement handles of DBD::mysql and DBD::mSQL support a number
@@ -402,7 +413,7 @@ header of table names together with all rows:
       }
       print "\n";
   }
-x
+
 For portable applications you should restrict yourself to attributes with
 capitalized or mixed case names. Lower case attribute names are private
 to DBD::mSQL and DBD::mysql. The attribute list includes:
@@ -564,15 +575,11 @@ Deprecated, should be replaced by the respective lower case names.
 =head1 BUGS
 
 The I<port> part of the first argument to the connect call is
-implemented in an unsafe way. In fact it never did more than set
-the environment variable MSQL_TCP_PORT during the connect call. If
-another connect call uses another port and the handles are used
-simultaneously, they will interfere. In a future version this
-behaviour will hoefully change, depending on David and Monty. :-)
-
-The func method call on a driver handle seems to be undocumented in
-the DBI manpage. DBD::mSQL has func methods on driverhandles, database
-handles, and statement handles. What gives?
+implemented in an unsafe way when using mSQL. In fact it is just
+stting the environment variable MSQL_TCP_PORT during the connect
+call. If another connect call uses another port and the handles
+are used simultaneously, they will interfere. I doubt that this
+will ever change.
 
 Please speak up now (June 1997) if you encounter additional bugs. I'm
 still learning about the DBI API and can neither judge the quality of
@@ -660,6 +667,35 @@ such as books, magazine articles or CD-ROMs should be made to
 Alligator Descartes <I<descarte@hermetica.com>>.
 
 
+=head1 MAILING LIST SUPPORT
+
+This module is maintained and supported on a mailing list,
+
+    msql-mysql-modules@tcx.se
+
+To subscribe to this list, send a mail with the words
+
+    subscribe msql-mysql-modules
+
+or
+
+    subscribe msql-mysql-modules-digest
+
+in the first line of the body to mdomo@tcx.se. A mailing list archive is
+in preparation.
+
+Additionally you might try the dbi-user mailing list for questions about
+DBI and its modules in general. Subscribe via
+
+    http://www.fugue.com/dbi
+
+Mailing list archives are at
+
+     http://www.rosat.mpe-garching.mpg.de/mailing-lists/PerlDB-Interest/
+     http://outside.organic.com/mail-archives/dbi-users/
+     http://www.coe.missouri.edu/~faq/lists/dbi.html
+
+
 =head1 ADDITIONAL DBI INFORMATION
 
 Additional information on the DBI project can be found on the World
